.. module:: cobyqa.framework

Trust-region framework
======================

This module implements classes for representing the trust-region framework used by COBYQA.

.. currentmodule:: cobyqa.framework

.. autosummary::
    :toctree: generated/

    TrustRegion
